
# Stilus

[![Travis (.org) branch](https://img.shields.io/travis/jw/stilus/master.svg?style=flat-square)](https://travis-ci.org/jw/stilus)
[![Codecov branch](https://img.shields.io/codecov/c/github/jw/stilus/master.svg?style=flat-square)](https://codecov.io/gh/jw/stilus)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/stilus.svg?style=flat-square)](https://pypi.org/project/stilus/#files)
[![PyPI](https://img.shields.io/pypi/v/stilus.svg?style=flat-square)](https://pypi.org/project/stilus/#history)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/stilus.svg?style=flat-square)](https://pypi.org/project/stilus/#description)
[![PyPI - License](https://img.shields.io/pypi/l/stilus?style=flat-square)](https://pypi.org/project/stilus/)

A Stylus css compiler in Python.

## Installation

Install and update using [pip](https://pypi.org/project/pip/):

    $ python -m pip install -U stilus

or 

    $ pip install -U stilus

## Documentation

There is [some documentation](https://stilus.readthedocs.io) available.

## Missing

Some parts of Stylus are not in Stilus yet:

 - Caching
 - Plugins
 - Documentation

All help is appreciated!
